<h1 align="center">
  <br>
  <a href="https://github.com/mohamed-hachaichi/Geosis"><img src="https://github.com/mohamed-hachaichi/app/blob/main/Geosis.png" alt="" width="200"></a>
  <br>
  Geosis
  <br>
</h1>

<h4 align="center">A powerful geographic analysis tool on top of <a href="https://www.python.org/" target="_blank">Python</a>.</h4>


<div id="top"></div>


<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/othneildrew/Best-README-Template">
    <img src="images/logo.png" alt="Logo" width="160" height="160">
  </a>

  <h3 align="center">Geosis</h3>

  <p align="center">
A machine learning-based package for spatial analysis
    <br />
    <a href="https://github.com/mohamed-hachaichi/Geosis"><strong>Explore the docs »</strong></a>

  </p>
</div>



<!-- TABLE OF CONTENTS -->
<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#roadmap">Roadmap</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
    <li><a href="#acknowledgments">Acknowledgments</a></li>
  </ol>
</details>



<!-- ABOUT THE PROJECT -->
## About The Project

The geography of knowledge production represents the method by which local scientific output are accepted, produced and debated elsewhere. However, in order to analyze geographic data, one must look for trends, networks, evolutions and relationships. However, while open source and free software started attracting academic from various disciplines, several handicaps persist such as (i) synthesizing the bottom-up knowledge production, (ii) inspect the genealogy of a given field, (iii) displaying the spatial distribution of the field across territories, and (iv) unpacking the spatial community network structure. Geosis is an artificial intelligence-based package developed to reply to such questions in a fast and easily process using large-scale textual data. The input data goes into three main data preprocessing stages. The first is a geoparsing module where the textual data became geo-referenced. The second is a natural language processing (NLP) module where data is synthesized and major themes are extracted. The third is network analysis module where research community on the field is mapped and major field producers are unveiled.  To our knowledge, our package is considered to be the first package that can unpack all the aspects of “knowledge production” for any given field. 

<p align="right">(<a href="#top">back to top</a>)</p>



### Built With

This section should list any major frameworks/libraries used to bootstrap your project. Leave any add-ons/plugins for the acknowledgements section. Here are a few examples.

* [Pandas](https://pandas.pydata.org)
* [GeoPandas](https://geopandas.org/en/stable/)
* [NetworkX](https://networkx.org)
* [Dask](https://www.dask.org)

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- GETTING STARTED -->
## Getting Started

To start using Geosis, you need to install: pandas, geopandas, dask, networkx, seaborn, and sklearn.

### Prerequisites

To install the package please inser the felowing code in your prompt:

* bach
  ```sh
  pip install pandas, geopandas, networkx, seaborn
  ```

### Installation

_Below is the code to install Geosis from the Pypi website._

1. Open your terminal. 
2. write the fellowing code:
   ```sh
   pip install geosis 
   ```


<p align="right">(<a href="#top">back to top</a>)</p>



<!-- USAGE EXAMPLES -->
## Usage

To have an brief introduction on how to use the package. Please read the article at: -waiting to be published-.

_For more examples, please refer to the [Documentation](https://example.com)_

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- ROADMAP -->
## Roadmap

- [x] Collect data from Scopus or Web of Science (WoS)
- [x] Read the data using Geosis' local functions 
- [ ] Add Additional Templates w/ Examples
- [ ] Add "components" document to easily copy & paste sections of the readme
- [x] Multi-language Support
    - [x] English
    - [ ] French
    - [ ] Chinese
    - [ ] Spanish

See the [open issues](https://github.com/mohamed-hachaichi/Geosis/issues) for a full list of proposed features (and known issues).

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- CONTRIBUTING -->
## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- LICENSE -->
## License

Distributed under the GNU GENERAL PUBLIC LICENSE. See `LICENSE.txt` for more information.

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- CONTACT -->
## Contact

Mohamed Hachiachi - [@datum_geek](https://twitter.com/datum_geek) - hachaichi_mohamed@outlook.com 

Project Link: [Geosis](https://github.com/mohamed-hachaichi/Geosis)

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- ACKNOWLEDGMENTS -->
## Acknowledgments

The python package is accessible from PyPI following the link: . Note that the package will be maintained, and new releases will be available in the future expanding its geographical analysis scope and providing much more capabilities and mapping options. Geosis is built on: Pandas, GeoPandas, and NetworkX.

<p align="right">(<a href="#top">back to top</a>)</p>